#
# spec file for package FreeCAD
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define x_prefix %{_libdir}/%{name}

%if 0%{?suse_version} > 1500
%bcond_without boost_signals2
%else
%bcond_with    boost_signals2
%endif
%bcond_with    smesh_external
%bcond_without smesh

Name:           FreeCAD
Version:        0.20.2
Release:        bp155.1.28
Summary:        General Purpose 3D CAD Modeler
License:        GPL-2.0-or-later AND LGPL-2.0-or-later
Group:          Productivity/Graphics/CAD
URL:            https://www.freecadweb.org/
Source0:        https://github.com/FreeCAD/FreeCAD/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Gui-Quarter-Add-missing-OpenGL-includes.patch
# PATCH-FIX-OPENSUSE
Patch1:         0001-Avoid-catching-SIGSEGV-defer-to-system-services.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-Fix-build-with-NG-6.2.2201-include-BRepMesh_Incremen.patch
# PATCH-FIX-UPSTREAM
Patch3:         0001-Part-OCCError.h-remove-unneeded-includes.patch
# PATCH-FIX-UPSTREAM
Patch4:         0001-Drawing-add-missing-include.patch
# PATCH-FIX-UPSTREAM
Patch5:         0001-FEM-add-missing-include.patch
# PATCH-FIX-UPSTREAM
Patch6:         0001-Revert-unused-parameter-warning-change.patch
# PATCH-FIX-UPSTREAM
Patch7:         0001-FEM-femmesh-fix-AttributeError-module-numpy-has-no-a.patch
# PATCH-FIX-OPENSUSE submitted upstream here: https://github.com/FreeCAD/FreeCAD/pull/9077
Patch8:         0001-Fix-build-with-gcc13.patch

# Test suite fails on 32bit and I don't want to debug that anymore
ExcludeArch:    %ix86 %arm ppc s390 s390x

BuildRequires:  libboost_filesystem-devel >= 1.55
BuildRequires:  libboost_graph-devel >= 1.55
BuildRequires:  libboost_program_options-devel >= 1.55
BuildRequires:  libboost_regex-devel >= 1.55
%if %{without boost_signals2}
BuildRequires:  libboost_signals-devel >= 1.55
%endif
BuildRequires:  libboost_serialization-devel >= 1.55
BuildRequires:  libboost_system-devel >= 1.55
BuildRequires:  libboost_thread-devel >= 1.55

BuildRequires:  cmake
BuildRequires:  double-conversion-devel
BuildRequires:  eigen3-devel
BuildRequires:  fdupes
BuildRequires:  glew-devel
BuildRequires:  hdf5-devel
BuildRequires:  hicolor-icon-theme
%if %{with smesh_external}
# We use the internal smesh version with fixes atm
BuildRequires:  smesh-devel
%endif
BuildRequires:  libXerces-c-devel
BuildRequires:  libXi-devel
BuildRequires:  libmed-devel
BuildRequires:  libspnav-devel
BuildRequires:  make
BuildRequires:  netgen-devel
BuildRequires:  occt-devel
BuildRequires:  pkg-config
BuildRequires:  proj-devel
BuildRequires:  sqlite3-devel

# Qt5 & python3
BuildRequires:  python3-devel >= 3.6.9
BuildRequires:  python3-matplotlib
BuildRequires:  python3-pivy
BuildRequires:  python3-ply
BuildRequires:  python3-pybind11-devel
BuildRequires:  python3-pycxx-devel
BuildRequires:  python3-pyside2-devel
BuildRequires:  python3-vtk
BuildRequires:  python3-xml
BuildRequires:  cmake(coin)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
Requires:       python3-numpy
Requires:       python3-pyside2
Requires:       python3-vtk
# For Arch & Draft workbench
Requires:       python3-pivy
# For FEM workbench
Requires:       python3-PyYAML
Requires:       python3-matplotlib-qt5
Requires:       python3-ply
Requires:       python3-six

BuildRequires:  swig
BuildRequires:  update-desktop-files
BuildRequires:  vtk-devel
BuildRequires:  zlib-devel

Recommends:     ccx

Provides:       freecad

%description
FreeCAD is a parametric 3D modeler made primarily to design real-life objects
of any size. Parametric modeling allows modifying designs by
going back into the model history and changing its parameters. FreeCAD is
customizable and scriptable.

%package devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contains the files needed for development with FreeCAD.

%prep
%setup -q
%autopatch -p1

# fix env-script-interpreter
sed -i '1c#!%{__python3}' \
        src/Mod/AddonManager/AddonManager.py \
        src/Mod/Mesh/App/MeshTestsApp.py \
        src/Mod/Robot/KukaExporter.py \
        src/Mod/Robot/MovieTool.py \
        src/Mod/Spreadsheet/importXLSX.py \
        src/Mod/TechDraw/TDTest/D*Test.py \
        src/Mod/Test/testmakeWireString.py

# Fix "wrong-script-end-of-line-encoding" rpmlint warning
sed -i 's/\r$//' src/Mod/Mesh/App/MeshTestsApp.py
sed -i 's/\r$//' src/Mod/Part/MakeBottle.py
sed -i 's/\r$//' src/Mod/PartDesign/Scripts/FilletArc.py
sed -i 's/\r$//' src/Mod/PartDesign/Scripts/Parallelepiped.py
sed -i 's/\r$//' src/Mod/PartDesign/Scripts/Spring.py
sed -i 's/\r$//' src/Mod/Robot/MovieTool.py
sed -i 's/\r$//' src/Mod/Robot/KukaExporter.py
sed -i 's/\r$//' src/Mod/Test/unittestgui.py

# Remove 3rd party libs
rm src/3rdparty/Pivy -fr
rm src/3rdparty/Pivy-0.5 -fr

# Resources are looked up relative to the binaries location,
# so all these need the same prefix, see src/App/Application.cpp
%build
%cmake \
  -DCMAKE_INSTALL_PREFIX=%{x_prefix} \
  -DCMAKE_INSTALL_LIBDIR=%{x_prefix}/lib \
  -DCMAKE_INSTALL_BINDIR=%{x_prefix}/bin \
  -DCMAKE_INSTALL_DATAROOTDIR=%{_datadir} \
  -DCMAKE_INSTALL_DATADIR=%{_datadir}/%{name} \
  -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name} \
  -DCMAKE_INSTALL_INCLUDEDIR=%{_includedir}/%{name} \
  -DCMAKE_SKIP_RPATH:BOOL=OFF \
  -DCMAKE_SKIP_INSTALL_RPATH:BOOL=OFF \
  -DCMAKE_INSTALL_RPATH_USE_LINK_PATH=ON \
  -DOCC_INCLUDE_DIR=%{_includedir}/opencascade \
  -DRESOURCEDIR=%{_datadir}/%{name} \
  -DPYTHON_EXECUTABLE=/usr/bin/python3 \
  -DPYTHON_INCLUDE_DIR=%{python3_sysconfig_path include} \
  -DSHIBOKEN_INCLUDE_DIR=/usr/include/shiboken2/ \
  -DPYSIDE_INCLUDE_DIR=/usr/include/PySide2/ \
  -DPYBIND11_FINDPYTHON:BOOL=ON \
  -DFREECAD_USE_PYBIND11:BOOL=ON \
  -DBUILD_ENABLE_CXX_STD:STRING="C++17" \
  -DBUILD_QT5=ON \
  -DFREECAD_USE_QT_DIALOG:BOOL=OFF \
  -DFREECAD_USE_EXTERNAL_PIVY:BOOL=TRUE \
  -DBUILD_OPENSCAD:BOOL=ON \
  -DBUILD_FLAT_MESH:BOOL=ON \
  -DFREECAD_USE_EXTERNAL_SMESH=%{?with_smesh_external:ON}%{!?with_smesh_external:OFF} \
  -DBUILD_SMESH:BOOL=ON \
  -DBUILD_MESH_PART:BOOL=ON \
  -DBUILD_FEM:BOOL=%{?with_smesh:ON}%{!?with_smesh:OFF} \
  -DBUILD_FEM_NETGEN:BOOL=ON \
  -DBUILD_FEM_VTK:BOOL=ON \
  -Wno-dev \
  ..

%cmake_build

%install
%cmake_install

# Fix "non-executable-script" rpmlint warning
# Run after install, as CMake "install(FILES...) sets rw- permissions
chmod 755 %{buildroot}%{_libdir}/FreeCAD/Mod/AddonManager/AddonManager.py \
          %{buildroot}%{_libdir}/FreeCAD/Mod/Robot/KukaExporter.py \
          %{buildroot}%{_libdir}/FreeCAD/Mod/Robot/MovieTool.py \
          %{buildroot}%{_libdir}/FreeCAD/Mod/Spreadsheet/importXLSX.py \
          %{buildroot}%{_libdir}/FreeCAD/Mod/TechDraw/TDTest/D*Test.py \
          %{buildroot}%{_libdir}/FreeCAD/Mod/Test/testmakeWireString.py

%suse_update_desktop_file -r org.freecadweb.FreeCAD Education Engineering

# Remove unneeded files
find %{buildroot} -type f -name "*.la" -delete -print
rm -Rf %{buildroot}%{_datadir}/pixmaps
# Broken
rm -Rf %{buildroot}%{_datadir}/thumbnailers

# Link binaries
mkdir -p %{buildroot}/usr/bin
ln -s -t %{buildroot}/usr/bin %{x_prefix}/bin/FreeCAD
ln -s -t %{buildroot}/usr/bin %{x_prefix}/bin/FreeCADCmd

%fdupes %{buildroot}/%{_libdir}
%fdupes %{buildroot}/%{_datadir}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md
%{_bindir}/FreeCAD{,Cmd}
%doc %{_docdir}/%{name}/
%{_libdir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/*/*.{png,svg}
%{_datadir}/metainfo/*.xml
%{_datadir}/mime/packages/*.xml

%changelog
* Mon Mar 27 2023 Adrian Schröter <adrian@suse.de>
- Fix build with gcc 13
  0001-Fix-build-with-gcc13.patch
* Thu Jan 26 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build after numpy 1.24 API changes, add
  0001-FEM-femmesh-fix-AttributeError-module-numpy-has-no-a.patch
* Fri Dec 30 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with OpenCASCADE 7.7.0, add
  * 0001-Part-OCCError.h-remove-unneeded-includes.patch
  * 0001-Drawing-add-missing-include.patch
  * 0001-FEM-add-missing-include.patch
  * 0001-Revert-unused-parameter-warning-change.patch
* Tue Dec  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.20.2:
  * Lots of bugfixes and new features, for details see
    https://wiki.freecad.org/Release_notes_0.20.2 and
    https://github.com/FreeCAD/FreeCAD/releases/tag/0.20.2
* Tue Aug 16 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.20.1:
  * Lots of bugfixes and new features, for details see
    https://wiki.freecad.org/Release_notes_0.20.1 and
    https://github.com/FreeCAD/FreeCAD/releases/tag/0.20.1
* Mon Aug 15 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Netgen 6.2.2201 and later, add
  0001-Fix-build-with-NG-6.2.2201-include-BRepMesh_Incremen.patch
* Tue Jun 14 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.20:
  * Lots of bugfixes and new features, for details see
    https://wiki.freecad.org/Release_notes_0.20 and
    https://github.com/FreeCAD/FreeCAD/releases/tag/0.20
- Drop upstream patches:
  * fix_unittestgui_tkinter_py3.patch
  * fix-smesh-vtk9.patch
  * 0001-Test-remove-not-needed-u-before-py3-unicode-string.patch
  * 0001-Test-fix-exception-handling-in-tests-for-units.patch
  * 0001-Test-Provide-more-useful-information-when-unit-trans.patch
  * 0002-Base-Fix-wrong-character-encoding-for-micro-siemens.patch
  * 0001-improve-search-for-VTK-9.patch
- Add 0001-Gui-Quarter-Add-missing-OpenGL-includes.patch
- Add 0001-Avoid-catching-SIGSEGV-defer-to-system-services.patch
* Wed Mar 16 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove VTK::Java/java-devel dependency, add
  0001-improve-search-for-VTK-9.patch
* Thu Mar 10 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use current Coin4 instead of Coin (3).
* Fri Mar  4 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add some unit test fixes:
  * 0001-Test-remove-not-needed-u-before-py3-unicode-string.patch
  * 0001-Test-fix-exception-handling-in-tests-for-units.patch
  * 0001-Test-Provide-more-useful-information-when-unit-trans.patch
  * 0002-Base-Fix-wrong-character-encoding-for-micro-siemens.patch
* Thu Mar  3 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.19.4:
  * Lots of bugfixes, for details see
    https://github.com/FreeCAD/FreeCAD/releases/tag/0.19.4
* Sun Feb  6 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Pre-generate parsetab.py for ply.yacc in OpenSCAD and FEM Mods:
  https://tracker.freecadweb.org/view.php?id=4840
* Fri Jan 14 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.19.3:
  * Lots of bugfixes, for details see
    https://github.com/FreeCAD/FreeCAD/releases/tag/0.19.3
* Sun Jun 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Replace the QtWebKit build dependency with QtWebEngine.
* Tue Apr 27 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.19.2:
  * Various bug fixes, no changelog provided
* Mon Mar 22 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.19.1:
  * Lots of new features, bug fixes and improvements, see
    https://wiki.freecadweb.org/Release_notes_0.19
- Drop upstream patches:
  * 0001-Fix-build-with-pyside2-shiboken2-5.12.1.patch
  * 0003-qt-5.14.patch
  * update-swigpyrunin-for-python-3.8.patch
  * 0001-fem-use-time.process_time-instead-of-removed-time.cl.patch
  * fix_qt_5.15_build.patch
  * 0001-boost-1.73.0-The-practice-of-declaring-the-Bind-plac.patch
  * 0001-Fix-ODR-violation-correct-Ui_TaskSketcherGeneral-nam.patch
  * 0001-Gui-skip-ci-fix-Wodr.patch
  * 0001-Part-Import-skip-ci-disable-use-of-Message_ProgressI.patch
  * 0001-import-Hotfix-for-build-failure-from-bad-debug-code.patch
  * 0001-partdesign-fix-failing-tapered-hole-test.patch
  * 0001-add-missing-std-namespace-to-build-on-Debian-10.patch
- Rebase fix-smesh-vtk9.patch
* Tue Feb 23 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build and tests with OCCT 7.5, add
  0001-Part-Import-skip-ci-disable-use-of-Message_ProgressI.patch
  0001-import-Hotfix-for-build-failure-from-bad-debug-code.patch
  0001-partdesign-fix-failing-tapered-hole-test.patch
- Add 0001-add-missing-std-namespace-to-build-on-Debian-10.patch
- Cleanup specfile:
  * Use system PyCXX, drop unused libboost_python3
  * Drop some unused dependencies
  * Remove ChangeLog.txt, not updated since version 0.14
* Mon Jan  4 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with latest GCC, add 0001-Gui-skip-ci-fix-Wodr.patch
- Force-enable C++17, Boost 1.75 requires C++14 at least
* Sat Nov 28 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.18.5:
  * Fix addon manager to adapt to GitHub infrastructure changes.
  * Add 0001-Fix-ODR-violation-correct-Ui_TaskSketcherGeneral-nam.patch
  * Rebase 0001-boost-1.73.0-The-practice-of-declaring-the-Bind-plac.patch
- Reenable workbenches dependent on Mesher (e.g. Path, FEM):
  * Add fix-smesh-vtk9.patch
* Sat Sep 19 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with boost 1.73 and later, add
  0001-boost-1.73.0-The-practice-of-declaring-the-Bind-plac.patch
- Cleanup some build dependencies.
* Thu Jul 23 2020 Adrian Schröter <adrian@suse.de>
- temporary disable FEM module until VTK 9 support arrives
* Sun Jun  7 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Qt 5.15, add fix_qt_5.15_build.patch
* Wed Mar 18 2020 Yunhe Guo <i@guoyunhe.me>
- Allow install with lowercase package name: zypper install freecad
* Mon Mar 16 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- More spec file cleanup, removed duplicate files
- Use upstream provided desktop files, mimeinfo, etc
* Sun Mar 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix runtime errors with Python 3.8:
  * 0001-fem-use-time.process_time-instead-of-removed-time.cl.patch
- Fix last python2 she-bang remainders, fix imports:
  * fix_unittestgui_tkinter_py3.patch
- Remove unnecessary opencv build dependency
- update to current 0.18 branch:
  * Fem: fix segmentation fault when opening contraint transform
    panel. Fix Python code
  * Part: the number of domains returned by TopoShape::getDomains
    must match with number of faces
  * apply fixes from master when building with occt 7.4
    + Drop 0002-fix-compile.patch
* Sat Mar 14 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Python 3.8:
  Add update-swigpyrunin-for-python-3.8.patch
- Spec file cleanup
  * Drop xpm FreeCAD icon
  * Install PNGs/SVG icons in correct paths
  * Remove obsolete update_mime_database calls in %%post
  * Remove obsolete conditionals for Leap 42.x
* Sat Jan 25 2020 Hans-Peter Jansen <hpj@urpla.net>
- make 0003-qt-5.14.patch do what it is advertising
  * fix conditional in order to locate rcc/uic properly
* Fri Jan 24 2020 Adrian Schröter <adrian@suse.de>
- update to current 0.18 branch:
  * fixes #0004182: Segfault when clicking constraints from a
    different viewport [skip ci]
  * [Draft] ImportDXF 0.18 Bug upgrading from 0.16. See discussion
    https://forum.freecadweb.org/viewtopic.php?f=3&t=41879
  * fixes #0004233: Access violation and file corruption on undo
    duplicate sketch
  * FEM: py3 fix in selection widget
  * FEM: selection widgets, add some error prints
  * FEM: equations, fix reset edit mode
  * [AddonManager] 0.18 Improve Non GitPython Error Handling.
    Previous output when clicking Macros tab caused errors in
    Report View with no Macros loaded at all.
  * fix encoding problem when clicking a link on StartPage if
    application is installed into a directory with non-ASCII characters
  * [Arch] ArchMaterial 0.18 Fix Crash
* Thu Jan 23 2020 Adrian Schröter <adrian@suse.de>
- fix build with new gcc and Qt 5.14
  (0002-fix-compile.patch 0003-qt-5.14.patch)
* Wed Oct 30 2019 Adrian Schröter <adrian@suse.de>
- Update to final 0.18.4
  * pre-select name filter in import/export file dialog
* Tue Oct 22 2019 Adrian Schröter <adrian@suse.de>
- update to current 0.18 branch, esp for Qt >= 5.9 fixes
  * [TD]Fix slow GC of QGIPrimPath
  * [Spreadsheet] Excel File Import fix Py3 bug
  * [Path] Fix xrange bug with Py3
  * fix print preview function for >= Qt 5.9
  * Backport: startwb files restored in 0.18.3 to display thumbs correctly
  * 0.18.x displays the example files within in the Start WB without their
    respective thumbs. This PR restores that functionality
  * Fixed problems with 'pythonopen'
  * Correction of drill speed calculation
  * Material: py2 fix in depreciated mat file parser (back port from 0.19)
  * [TD]Fix #4017 Crash on bad hatch scale
* Thu Jul 18 2019 Adrian Schröter <adrian@suse.de>
- Update to 0.18.3
  * AddonManager: Skip non-github addons
  * Sketcher: Fix Carbon copy leads to unsolvable sketch
  * Sketcher: Fix carbon copy construction points
  * fixes #0003993: Memory leak with Python3
  * code simplification in PythonWrapper
  * issue #0003984: Creating a Path Job object fails with 'PySide2.QtWidgets.QDialog' object has no attribute 'templateGroup'
  * Fixes bug #4008: removes phantom path cause
  * Fix crash in case encoding of Python paths fails
  * [Material] Respect unicode filenames Fixes #4027
  * BrowserView: fix QWebEngine crash
  * Py3: no __builtin__ module available
  * fixes 0004010: Box Selection + Part -> MakeCompound will crash FreeCAD
  * FEM: solver elmer tasks, Py3 decode fix
  * make OpenSCAD utilities working again with Py2
* Fri Jul 12 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove MPI dependencies, as these are not used for the built package,
  but adversely affect build times and rebuilds.
  Proper MPI integration needs more work and has to ensure the base version
  of FreeCAD can be used without prior manual setup of an MPI environment.
  Remove 0001-find-openmpi2-include-files.patch, mpicc/mpicxx would
  pick up the correct include path by themselfs.
- Sort BuildRequires: again
* Thu Jun 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Fix-build-with-pyside2-shiboken2-5.12.1.patch to fix
  build with recent shiboken2/pyside2 releases.
* Sun May 12 2019 Adrian Schröter <adrian@suse.de>
- Update to 0.18.2
  * replace insecure use of eval() with proper use of units
  * py3/py2: use exec as function
  * Arch: Fixed error in roof - Fixes #3864
  * Draft: Fixed 0.18.1 bug in DXF importer
  * Py3 fix: correctly convert a Python str to const char*
  * Py3 fix reading/writing from/to OBJ file
  * fixes 0003913: libspnav crash on linux wayland during startup
* Fri Apr  5 2019 Adrian Schröter <adrian@suse.de>
- Update to 0.18.1
  * FEM module fixes
  * crash fixes
  * Qt5 bugs with external display
* Mon Mar 25 2019 Adrian Schröter <adrian@suse.de>
- add missing requires to six and vtk python modules (found via test suite)
* Mon Mar 18 2019 Adrian Schröter <adrian@suse.de>
- Update to release 0.18
  * NetGen FEM enabled
  * 0001-find-openmpi2-include-files.patch added for openmpi2 support
- Obsolete patches:
  * 0001-Convert-deprecated-boost-signal-to-signals2.patch
  * 0001-Use-GL_RGB32F-instead-of-GL_RGB32F_ARB.patch
  * 0002-move-from-deprecated-boost.signals-to-boost.signals2.patch
  * 0003-fix-blocking-of-SelectionObserver.patch
  * fix-build-with-Qt5_11.diff
  * fix-build.diff
  * fix-draft-module-with-python3.patch
  * fix-gcc8-build-failure.patch
  * get-rid-of-private-function-_PyImport_FixupBuiltin-for-FreeCAD-and-FreeCADGui-modules.patch
  * get-rid-of-private-function-_PyImport_FixupBuiltin-for-__FreeCADBase__-module.patch
* Thu Mar 14 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add support for Boost::Signals2, Boost::Signals has been deprecated
  since Boost 1.54 and removed in 1.69:
  * 0001-Convert-deprecated-boost-signal-to-signals2.patch
  * 0002-move-from-deprecated-boost.signals-to-boost.signals2.patch
  * 0003-fix-blocking-of-SelectionObserver.patch
- Add explicit double-conversion-devel BuildRequires
* Sat Mar  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update URL: to use https://
- Reorder BuildRequires alphabetically, remove duplicates
* Fri Feb 15 2019 Jan Engelhardt <jengelh@inai.de>
- Generalize description, and strip info that is already in
  the metadata.
* Thu Feb 14 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with GCC 8, add fix-gcc8-build-failure.patch
- Add 0001-Use-GL_RGB32F-instead-of-GL_RGB32F_ARB.patch, fix building
  on AArch64.
- Remove openmpi build dependencies, erroneously required for VTK
  previously.
  Drop 0001-find-openmpi2-include-files.patch
* Tue Feb 12 2019 Adrian Schröter <adrian@suse.de>
- enable FEM module
- disable builds for 32bit and s390x, test suite fails and it makes no
  sense to use FreeCAD on small systems or mainframes...
* Mon Feb  4 2019 Adrian Schröter <adrian@suse.de>
- update to current branch:
  - Spreadsheet: Fixed issue #3361.
* Fri Feb  1 2019 wbauer@tmo.at
- Add upstream patches to fix build with python 3.7:
  * get-rid-of-private-function-_PyImport_FixupBuiltin-for-__FreeCADBase__-module.patch
  * get-rid-of-private-function-_PyImport_FixupBuiltin-for-FreeCAD-and-FreeCADGui-modules.patch
* Wed Sep  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Aug 28 2018 Adrian Schröter <adrian@suse.de>
- fix missing dependency to numpy, found via the..
- added testsuite run via extra spec file
* Sat Aug 11 2018 adrian@suse.de
- update branch again
- fix dependencies of Qt4 build (Leap 42.3)
* Thu Jul 26 2018 adrian@suse.de
- update to current branch, obsoletes branch_update.patch
* Mon Jun 18 2018 stefan.bruens@rwth-aachen.de
- Fix BuildRequires, TW no longer has libboost_python-devel but
  libboost_python3-devel, and for Leap 15.0 this linked libpython3.6m
  and libboost_python-py2_7 into the same binary.
* Sun May 20 2018 christophe@krop.fr
- Add fix-build-with-Qt5_11.diff. Fixes build with the upcoming
  Qt 5.11.
- Switch to %%autosetup
* Tue May  8 2018 adrian@suse.de
- temporary disable FEM module
  * it works fine, but requires hdf5 version 1.8 via med-tools,
    which currently conflicts in openSUSE distro.
- Fix draft module crash
  (got merged upstream for 0.18 fix-draft-module-with-python3.patch)
* Fri Apr 27 2018 adrian@suse.de
- apply current 0.17 branch (branch_update.patch)
  In first place for occt 7.2 fixes
* Tue Apr 17 2018 adrian@suse.de
- fix crash in Draft module with python 3
* Mon Apr 16 2018 adrian@suse.de
- cleanup python qt deps (pyside2 only now)
* Tue Apr 10 2018 adrian@suse.de
- update to version 0.17
  2 years of work: https://www.freecadweb.org/wiki/Release_notes_0.17
- switching to Qt5
  (fix-build.diff 0001-find-openmpi2-include-files.patch)
  (the old 0.16 fork had obsolete temporary patches remove-qtwebkit.patch and
  remove-webgui.patch)
* Thu Jan  4 2018 wbauer@tmo.at
- Add remove-qtwebkit.patch and remove-webgui.patch (taken from
  Arch Linux) to fix build without QtWebKit
- Build without QtWebKit on Tumbleweed and SLE/Leap 15 as
  libQtWebKit4 is about to be dropped (boo#1070901)
* Fri Dec 15 2017 adrian@suse.de
- fix build for factory (boost dependencies)
* Wed Nov  8 2017 aloisio@gmx.com
- Update to 0.16.6712 (contains backports from trunk)
- Some cleanup
* Sun Sep 10 2017 rbrown@suse.com
- Correct python-CXX requires
- add python-pyside requires, needed for welcome splash
* Mon Jun 13 2016 adrian@suse.de
- FreeCAD 0.16
- create on the base of the work from various home projects
  (esp by wkazubski and torhans)
- use rpath instead of modifying ldconfig for our own libs
